import 'package:fast_immutable_collections/fast_immutable_collections.dart';
import 'package:meta/meta.dart';
import 'package:notice/src/notice_level.dart';

/// A record of a notice log.
class NoticeRecord {
  const NoticeRecord({
    required this.level,
    required this.message,
    required this.error,
    required this.stackTrace,
    required this.timestamp,
    required this.breadcrumbs,
  });

  /// The level of the log.
  final NoticeLevel level;

  /// The message of the log.
  final String message;

  /// The error of the log, if any.
  final Object? error;

  /// The stack trace of the log, if any.
  final StackTrace? stackTrace;

  /// The timestamp of the log.
  final DateTime timestamp;

  /// The collected breadcrumbs of the log.
  final IList<String> breadcrumbs;

  @internal
  NoticeRecord copyWithBreadcrumb(String breadcrumb) {
    return NoticeRecord(
      level: level,
      message: message,
      error: error,
      stackTrace: stackTrace,
      timestamp: timestamp,
      // append breadcrumb to the front of the list
      breadcrumbs: breadcrumbs.insert(0, breadcrumb),
    );
  }
}
